@@ -15,4 +15,4 @@ class Attendance(Base): #pylint: disable=[too-few-public-methods]
     name_of_class = "attendances"
 
     def __repr__(self):
-        return super().__repr__(['cohort_member','session','status'])
+        return super().__repr__(['_id', 'cohort_member_id', 'session_id', 'status'])
