@@ -90,14 +90,15 @@ class Submission(Base): #pylint: disable=[too-few-public-methods]
                 btn.disabled = True
                 answer = answer.strip() if isinstance(answer, str) else ','.join(answer)
 
-                if self.assignment.assignment_type == "EXAM":
-                    # submit answer
-                    self.answers[q_index]['answer'] = answer
-                    self.answers[q_index]['clientCheck'] = 0
-                    _ = Submission.create(self.to_json())
-                    print('You have answered:', answer, sep='\n')
-                else:
-                    self.validate_answer(q_index, answer, global_dict)
+                # if self.assignment.assignment_type == "EXAM":
+                #     # submit answer
+                #     self.answers[q_index]['answer'] = answer
+                #     self.answers[q_index]['clientCheck'] = 0
+                #     _ = Submission.create(self.to_json())
+                #     print('You have answered:', answer, sep='\n')
+                # else:
+                #     self.validate_answer(q_index, answer, global_dict)
+                self.validate_answer(q_index, answer, global_dict)
                     
                 btn.description = "Submit"
                 btn.disabled = False
@@ -184,7 +185,8 @@ class Submission(Base): #pylint: disable=[too-few-public-methods]
             except Exception as e:
                 print(f'Something else went wrong\n  {e}')
             finally:
-                print(f'Your current score: {self.current_score}/{self.assignment.total_score}')
+                if self.assignment.assignment_type != 'EXAM':
+                    print(f'Your current score: {self.current_score}/{self.assignment.total_score}')
 
     @classmethod
     def initialize_submission(cls, assignment_id):
@@ -199,6 +201,8 @@ class Submission(Base): #pylint: disable=[too-few-public-methods]
             "answers": [{'question': q['question'], 'answer':'', 'clientCheck':-1} for q in assignment.questions],
             "currentScore": 0
         })
+        if assignment.assignment_type == 'EXAM':
+            Utils.DEBUG = False
 
         submission.assignment = assignment
         return submission
