@@ -509,7 +509,7 @@ def cohort_report(cohort_name, time_range={}, port=8051):
 
                 ],
                 align='center',
-                no_gutters=True
+                # no_gutters=True
             ),
             href="#"
         ),
